@@ -2,20 +2,24 @@
 /*
  *  Authors: Iain Holmes <iain@prettypeople.org>
  *
- *  Copyright 2002 Iain Holmes
+ * Copyright 2002, 2003, 2004, 2005 Iain Holmes
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of version 2 of the GNU General Public
- *  License as published by the Free Foundation.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ * 4th Februrary 2005: Christian Schaller: changed license to LGPL with 
+ * permission of Iain Holmes, Ronald Bultje, Leontine Binchy (SUN), Johan Dahlin *  and Joe Marcus Clarke
  *
  */
 
@@ -83,12 +87,14 @@ gsr_open_window (const char *filename)
 	if (filename == NULL) {
 		static int sample_count = 1;
 
-		if (sample_count != 1) {
-			name = g_strdup_printf ("Untitled-%d", sample_count);
-		} else {
-			name = g_strdup ("Untitled");
-		}
-
+		/* Translator comment: untitled here implies that
+		 * there is no active sound sample. Any newly
+		 * recorded samples will be saved to disk with this
+		 * name as default value. */
+		name = g_strdup_printf (ngettext("Untitled",
+						 "Untitled-%d",
+						 sample_count),
+						 sample_count);
 		sample_count++;
 	} else {
 		name = g_strdup (filename);
