@@ -31,9 +31,9 @@
  
 /* Test specified inputs for pipelines */
 /* static const gchar audiosink_test_pipe[] = "afsrc location=\"" TEST_MEDIA_FILE "\""; FIXME*/
-static gchar audiosink_test_pipe[] = "sinesrc freq=512 ! audioconvert";
+static gchar audiosink_test_pipe[] = "sinesrc freq=512";
 /* ffmpegcolorspace is the ripped colorspace element in gst-plugins */
-static gchar videosink_test_pipe[] = "videotestsrc ! ffmpegcolorspace";
+static gchar videosink_test_pipe[] = "videotestsrc";
 
 static gchar GSTPROPS_KEY_DEFAULT_VIDEOSINK[] = "default/videosink";
 static gchar GSTPROPS_KEY_DEFAULT_VIDEOSRC[] = "default/videosrc";
@@ -58,6 +58,8 @@ GSTPPipelineDescription audiosink_pipelines[] = {
 #endif
 	{PIPE_TYPE_AUDIOSINK, 0,"OSS - Open Sound System", 
 	 "osssink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, TRUE},
+	{PIPE_TYPE_AUDIOSINK, 0,"Polypaudio Sound Server", 
+	 "polypsink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
 	{PIPE_TYPE_AUDIOSINK, 0, N_("Custom"), NULL, TRUE, TEST_PIPE_SUPPLIED,
 	 audiosink_test_pipe, TRUE}
 };
@@ -95,6 +97,8 @@ GSTPPipelineDescription audiosrc_pipelines[] = {
 #endif
 	{PIPE_TYPE_AUDIOSRC, 0,"OSS - Open Sound System", "osssrc", FALSE,
 	 TEST_PIPE_AUDIOSINK, NULL, FALSE},
+	{PIPE_TYPE_AUDIOSRC, 0,"Polypaudio Sound Server", "polypsrc", FALSE,
+	 TEST_PIPE_AUDIOSINK, NULL, FALSE},
 	{PIPE_TYPE_AUDIOSRC, 0,"Silence", "silence", FALSE, TEST_PIPE_AUDIOSINK,
 	 NULL, FALSE},
 	{PIPE_TYPE_AUDIOSRC, 0, N_("Custom"), NULL, TRUE, TEST_PIPE_AUDIOSINK, NULL,
